package com.ruoyi.web.modules.industrypolicy.mapper;

import java.util.List;
import com.ruoyi.web.modules.industrypolicy.domain.BizIndustryPolicyPublicity;

/**
 * 产业政策宣传 Mapper
 */
public interface BizIndustryPolicyPublicityMapper
{
    BizIndustryPolicyPublicity selectBizIndustryPolicyPublicityById(Long id);

    List<BizIndustryPolicyPublicity> selectBizIndustryPolicyPublicityList(BizIndustryPolicyPublicity query);

    int insertBizIndustryPolicyPublicity(BizIndustryPolicyPublicity row);

    int updateBizIndustryPolicyPublicity(BizIndustryPolicyPublicity row);

    int deleteBizIndustryPolicyPublicityByIds(Long[] ids);
}
